package cn.pluss.platform.activityConsumReturn;

import java.util.List;
import java.util.Map;

import cn.pluss.platform.entity.ActivityConsumReturn;
import cn.pluss.platform.entity.MerchantMenberComsume;
import cn.pluss.platform.mapper.ActivityConsumReturnMapper;
import com.baomidou.mybatisplus.extension.service.IService;

public interface ActivityConsumReturnService extends IService<ActivityConsumReturn> {

    ActivityConsumReturn queryActivityConsumReturn(ActivityConsumReturn activityConsumReturn);

    List<ActivityConsumReturn> queryActivityConsumReturnList(ActivityConsumReturn activityConsumReturn);

    void saveActivityConsumReturn(ActivityConsumReturn activityConsumReturn);

    void updateActivityConsumReturn(ActivityConsumReturn activityConsumReturn);

    void deleteActivityConsumReturn(ActivityConsumReturn activityConsumReturn);

    List<ActivityConsumReturn> queryActivityConsumReturnPage(Map map);

    List<ActivityConsumReturn> queryActivityNoConsumReturnPage(Map map);

    Integer queryActivityConsumReturnPageCount(Map map);

    Integer queryActivityNoConsumReturnPageCount(Map map);

    void saveActivityConsumReturnBatch(List<ActivityConsumReturn> activityConsumReturnList);

    /**
     * 获取消费返现参数
     */
    MerchantMenberComsume getActivityReturnParams(String merchantCode, String storeId, Double consumeAmt);

    /**
     * 根据用户id删除所有“充值返”活动
     *
     * @param userId
     */
    void delByUserId(Integer userId);
}

